<?php
include_once(ABSPATH . 'wp-admin/includes/admin.php');
include_once(ABSPATH . WPINC . '/class-IXR.php');
include_once(ABSPATH . WPINC . '/class-wp-xmlrpc-server.php');

class TestXMLRPCServer_Disabled extends WPTestCase {
	function test_disabled() {
		$myxmlrpcserver = new wp_xmlrpc_server();
		$result = $myxmlrpcserver->wp_getOptions( array( 1, 'username', 'password' ) );
		
		$this->assertInstanceOf( 'IXR_Error', $result );
		$this->assertEquals( 405, $result->code );
	}
}

class TestXMLRPCServer_wp_getOptions extends WPTestCase {
	var $user_ids = array();

	function setUp() {

		parent::setUp();
		// keep track of users we create
		$user_ids = array();
		$this->_flush_roles();

		$this->orig_users = get_users_of_blog();
		add_filter( 'pre_option_enable_xmlrpc', '__return_true' );
	}

	function tearDown() {
		parent::tearDown();
		// delete any users that were created during tests
		foreach ($this->user_ids as $id)
			wp_delete_user($id);

		remove_filter( 'pre_option_enable_xmlrpc', '__return_true' );
	}

	function _flush_roles() {
		// we want to make sure we're testing against the db, not just in-memory data
		// this will flush everything and reload it from the db
		unset( $GLOBALS['wp_user_roles'] );
	}

	function test_invalid_username_password() {
		$myxmlrpcserver = new wp_xmlrpc_server();
		$result = $myxmlrpcserver->wp_getOptions( array( 1, 'username', 'password' ) );
		$this->assertInstanceOf( 'IXR_Error', $result );
		$this->assertEquals( 403, $result->code );
	}

	function test_valid_username_password() {
		$this->_make_user( 'subscriber', 'subscriber', 'subscriber' );
		$myxmlrpcserver = new wp_xmlrpc_server();
		$result = $myxmlrpcserver->wp_getOptions( array( 1, 'subscriber', 'subscriber' ) );
		$this->assertInternalType( 'array', $result );
		$this->assertEquals( 'WordPress', $result['software_name']['value'] );
	}

	function test_option_values() {
		$this->_make_user( 'subscriber', 'subscriber', 'subscriber' );
		$myxmlrpcserver = new wp_xmlrpc_server();
		$result = $myxmlrpcserver->wp_getOptions( array( 1, 'subscriber', 'subscriber', 'default_comment_status' ) );
		$this->assertInternalType( 'array', $result );
		$this->assertEquals( get_option( 'default_comment_status' ), $result['default_comment_status']['value'] );
	}

}